pub struct TimerId(/* private fields */);Expand description
Identifier for a timer scheduled by workflow code or by the engine.
Implementations
Sourceimpl TimerId
impl TimerId
Sourcepub fn named(name: impl Into<String>) -> Result<TimerId, IdError>
pub fn named(name: impl Into<String>) -> Result<TimerId, IdError>
Creates an author-assigned timer identifier.
Errors
Returns IdError::EmptyTimerName if the name is empty.
Sourcepub const fn anonymous(sequence_position: u64) -> TimerId
pub const fn anonymous(sequence_position: u64) -> TimerId
Creates an engine-assigned timer identifier derived from sequence position.
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
Returns the author-assigned timer name, if this is a named timer.
Sourcepub fn sequence_position(&self) -> Option<u64>
pub fn sequence_position(&self) -> Option<u64>
Returns the scheduling sequence position, if this is an anonymous timer.